<?PHP
/*
 
 Simfatic Forms provides you features to create the form data table that you see in
 form to email, confirm page etc. However this has a disadvantage that if there are several 
 elements that are not filled, you will still get the form data sections with empty values.

 ### Steps
 1. Add a hidden field MyCustomTable to the form
 2. Place a custom variable "%MyCustomTable%" in the confirmation template.
 3. Place MyCustomTable in the email template ( note: there is no % in the email template variable)

 The extension module replaces the "MyCustomTable" variable with the actual data table composed here. See the MakeCustomTable function below. It skips fields with values like 
0 or NaN (not a number) blank or $0.00 
*/

class CustomTableModule extends FM_ExtensionModule
{
    
    function BeforeConfirmPageDisplay(&$formvars)
    {
        $formvars["MyCustomTable"] = $this->MakeCustomTable($formvars);
        return true;
    }
    
    function BeforeSendingFormSubmissionEMail(&$receipient,&$subject,&$body)
    {
        $customtable = $this->MakeCustomTable($this->formvars);
        
        $body = str_replace('MyCustomTable', $customtable,$body);
    }
    
    function MakeCustomTable($formvars)
    {
        //return print_r($formvars,true);
        $customtable ="<table cellSpacing='0' cellPadding='5' border='0'>\n";
        foreach($formvars as $name => $value)
        {
            $value = trim($value);
            if(empty($value) || 'NaN' == $value || '$0.00' == $value )
            {
                continue;
            }
            if(is_numeric($value) && 0 == $value) 
            {
                continue;
            }
            if('ConfirmEmail' == $name)
            {
                continue;
            }

            if($this->config->element_info->IsElementPresent($name))
            {
               $customtable .= "<tr ><td class='FieldName'>$name</td><td class='FieldValue'>$value</td></tr>\n";
            }
        }
        $customtable .="</table>";
        return $customtable;
    }
}

